package eu.lucazanini.circlesurfaceview;

import android.content.Context;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.util.AttributeSet;
import android.view.SurfaceHolder;
import android.view.SurfaceView;

public class TouchSurfaceView extends SurfaceView implements
	SurfaceHolder.Callback {

    private final static String TAG = TouchSurfaceView.class.getName();
    private Circle circleOne, circleTwo;;
    private Thread mDrawingThread;
    private final SurfaceHolder mSurfaceHolder;

    public TouchSurfaceView(Context context, AttributeSet attrs) {
	super(context, attrs);

	circleOne = new Circle();
	circleTwo = new Circle();

	mSurfaceHolder = getHolder();
	mSurfaceHolder.addCallback(this);
    }

    public void setCircleOne(float x, float y, int action) {
	circleOne.setX(x);
	circleOne.setY(y);
	circleOne.setAction(action);
    }

    public void setCircleTwo(float x, float y, int action) {
	circleTwo.setX(x);
	circleTwo.setY(y);
	circleTwo.setAction(action);
    }

    @Override
    public void surfaceChanged(SurfaceHolder holder, int format, int width,
	    int height) {
    }

    @Override
    public void surfaceCreated(SurfaceHolder holder) {
	mDrawingThread = new Thread(new Runnable() {
	    @Override
	    public void run() {
		Canvas canvas = null;
		while (!Thread.currentThread().isInterrupted()) {

		    canvas = mSurfaceHolder.lockCanvas();

		    if (canvas != null) {

			Paint paint = new Paint();

			// draw white canvas
			paint.setStyle(Paint.Style.FILL);
			paint.setColor(Color.WHITE);
			canvas.drawRect(0, 0, getWidth(), getHeight(), paint);

			// draw the circles
			paint.setAntiAlias(true);
			if (circleOne != null && circleOne.getAction() != -1) {
			    paint.setColor(Color.RED);
			    canvas.drawCircle(circleOne.getX(),
				    circleOne.getY(), 100, paint);
			}
			if (circleTwo != null && circleTwo.getAction() != -1) {
			    paint.setColor(Color.GREEN);
			    canvas.drawCircle(circleTwo.getX(),
				    circleTwo.getY(), 100, paint);
			}

			mSurfaceHolder.unlockCanvasAndPost(canvas);
		    }
		}
	    }
	});
	mDrawingThread.start();
    }

    @Override
    public void surfaceDestroyed(SurfaceHolder holder) {
	if (mDrawingThread != null)
	    mDrawingThread.interrupt();
    }

    @Override
    protected void onMeasure(int widthMeasureSpec, int heightMeasureSpec) {
	int widthMode = MeasureSpec.getMode(widthMeasureSpec);
	int widthSize = MeasureSpec.getSize(widthMeasureSpec);
	int heightMode = MeasureSpec.getMode(heightMeasureSpec);
	int heightSize = MeasureSpec.getSize(heightMeasureSpec);

	setMeasuredDimension(widthSize, heightSize);
    }

}
